summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2015-07-09 11:04:53 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2015-07-09 11:14:03 -0500
commit4cb6607c89685a164f8836f101de6a8b845ace2d (patch)
tree0dc8cd9f7aa455b063d21b42948a961018b8d485
parent751eb368a8d0b2fa95ab46c83b22394038e7ea1b (diff)
downloadlibpng-1.6.18rc01.tar.gz
[libpng16] Imported from libpng-1.6.18rc01.tarv1.6.18rc01
-rw-r--r--ANNOUNCE18
-rw-r--r--CHANGES2
-rw-r--r--CMakeLists.txt2
-rw-r--r--README2
-rw-r--r--configure.ac4
-rw-r--r--libpng-manual.txt6
-rw-r--r--libpng.315
-rw-r--r--libpngpf.34
-rw-r--r--png.52
-rw-r--r--png.c6
-rw-r--r--png.h21
-rw-r--r--pngconf.h2
-rw-r--r--pngtest.c2
-rw-r--r--projects/vstudio/readme.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/README.txt10
-rw-r--r--scripts/def.c2
-rw-r--r--scripts/libpng-config-head.in2
-rw-r--r--scripts/libpng.pc.in2
-rw-r--r--scripts/makefile.ne12bsd2
-rw-r--r--scripts/makefile.netbsd2
-rw-r--r--scripts/makefile.openbsd2
-rw-r--r--scripts/pnglibconf.h.prebuilt4
-rw-r--r--scripts/symbols.def2
24 files changed, 60 insertions, 58 deletions
diff --git a/ANNOUNCE b/ANNOUNCE
index ed4de0bcb..d236dd17e 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,4 +1,4 @@
-Libpng 1.6.18beta10 - July 9, 2015
+Libpng 1.6.18rc01 - July 9, 2015
This is not intended to be a public release. It will be replaced
within a few weeks by a public version or by another test version.
@@ -8,20 +8,20 @@ Files available for download:
Source files with LF line endings (for Unix/Linux) and with a
"configure" script
- 1.6.18beta10.tar.xz (LZMA-compressed, recommended)
- 1.6.18beta10.tar.gz
+ 1.6.18rc01.tar.xz (LZMA-compressed, recommended)
+ 1.6.18rc01.tar.gz
Source files with CRLF line endings (for Windows), without the
"configure" script
- lp1618b10.7z (LZMA-compressed, recommended)
- lp1618b10.zip
+ lp1618r01.7z (LZMA-compressed, recommended)
+ lp1618r01.zip
Other information:
- 1.6.18beta10-README.txt
- 1.6.18beta10-LICENSE.txt
- libpng-1.6.18beta10-*.asc (armored detached GPG signatures)
+ 1.6.18rc01-README.txt
+ 1.6.18rc01-LICENSE.txt
+ libpng-1.6.18rc01-*.asc (armored detached GPG signatures)
Changes since the last public release (1.6.17):
@@ -102,7 +102,7 @@ Version 1.6.18beta09 [July 5, 2015]
preserve API compatibility, the new defines all default to "extern"
(requested by Jan Nijtmans).
-Version 1.6.18beta10 [July 9, 2015]
+Version 1.6.18rc01 [July 9, 2015]
Belatedly added Mans Rullgard and James Yu to the list of Contributing
Authors.
diff --git a/CHANGES b/CHANGES
index 762ada304..8ae43505f 100644
--- a/CHANGES
+++ b/CHANGES
@@ -5291,7 +5291,7 @@ Version 1.6.18beta09 [July 5, 2015]
preserve API compatibility, the new defines all default to "extern"
(requested by Jan Nijtmans).
-Version 1.6.18beta10 [July 9, 2015]
+Version 1.6.18rc01 [July 9, 2015]
Belatedly added Mans Rullgard and James Yu to the list of Contributing
Authors.
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 38ec532bd..4117eee5b 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -261,7 +261,7 @@ endif(NOT WIN32 OR CYGWIN OR MINGW)
# SET UP LINKS
if(PNG_SHARED)
set_target_properties(${PNG_LIB_NAME} PROPERTIES
-# VERSION 16.${PNGLIB_RELEASE}.1.6.18beta10
+# VERSION 16.${PNGLIB_RELEASE}.1.6.18rc01
VERSION 16.${PNGLIB_RELEASE}.0
SOVERSION 16
CLEAN_DIRECT_OUTPUT 1)
diff --git a/README b/README
index 3684f4322..29dd1596a 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.6.18beta10 - July 5, 2015 (shared library 16.0)
+README for libpng version 1.6.18rc01 - July 9, 2015 (shared library 16.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
diff --git a/configure.ac b/configure.ac
index fe0a0b40d..e2922caaf 100644
--- a/configure.ac
+++ b/configure.ac
@@ -18,7 +18,7 @@ AC_PREREQ([2.68])
dnl Version number stuff here:
-AC_INIT([libpng],[1.6.18beta10],[png-mng-implement@lists.sourceforge.net])
+AC_INIT([libpng],[1.6.18rc01],[png-mng-implement@lists.sourceforge.net])
AC_CONFIG_MACRO_DIR([scripts])
# libpng does not follow GNU file name conventions (hence 'foreign')
@@ -39,7 +39,7 @@ dnl automake, so the following is not necessary (and is not defined anyway):
dnl AM_PREREQ([1.11.2])
dnl stop configure from automagically running automake
-PNGLIB_VERSION=1.6.18beta10
+PNGLIB_VERSION=1.6.18rc01
PNGLIB_MAJOR=1
PNGLIB_MINOR=6
PNGLIB_RELEASE=18
diff --git a/libpng-manual.txt b/libpng-manual.txt
index 2f2c0a9d4..cdf34aa8d 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.6.18beta10 - July 9, 2015
+ libpng version 1.6.18rc01 - July 9, 2015
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.6.18beta10 - July 9, 2015
+ libpng versions 0.97, January 1998, through 1.6.18rc01 - July 9, 2015
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -5303,7 +5303,7 @@ Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.6.18beta10 are Y2K compliant. It is my belief that earlier
+upward through 1.6.18rc01 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has two year fields. One is a 2-byte unsigned integer
diff --git a/libpng.3 b/libpng.3
index 7985cf677..695940f9d 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
.TH LIBPNG 3 "July 9, 2015"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.6.18beta10
+libpng \- Portable Network Graphics (PNG) Reference Library 1.6.18rc01
.SH SYNOPSIS
\fB
#include <png.h>\fP
@@ -504,7 +504,7 @@ Following is a copy of the libpng-manual.txt file that accompanies libpng.
.SH LIBPNG.TXT
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.6.18beta10 - July 9, 2015
+ libpng version 1.6.18rc01 - July 9, 2015
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -515,7 +515,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.6.18beta10 - July 9, 2015
+ libpng versions 0.97, January 1998, through 1.6.18rc01 - July 9, 2015
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -5807,7 +5807,7 @@ Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.6.18beta10 are Y2K compliant. It is my belief that earlier
+upward through 1.6.18rc01 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -6062,7 +6062,8 @@ the first widely used release:
1.6.17beta01-06 16 10617 16.so.16.17[.0]
1.6.17rc01-06 16 10617 16.so.16.17[.0]
1.6.17 16 10617 16.so.16.17[.0]
- 1.6.18beta01-10 16 10618 16.so.16.18[.0]
+ 1.6.18beta01-09 16 10618 16.so.16.18[.0]
+ 1.6.18rc01 16 10618 16.so.16.18[.0]
Henceforth the source version will match the shared-library minor
and patch numbers; the shared-library major version number will be
@@ -6119,7 +6120,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.6.18beta10 - July 9, 2015:
+Libpng version 1.6.18rc01 - July 9, 2015:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
@@ -6142,7 +6143,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.0.7, July 1, 2000, through 1.6.18beta10, July 9, 2015, are
+libpng versions 1.0.7, July 1, 2000, through 1.6.18rc01, July 9, 2015, are
Copyright (c) 2000-2002, 2004, 2006-2015 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.0.6
with the following individuals added to the list of Contributing Authors:
diff --git a/libpngpf.3 b/libpngpf.3
index 8640375c4..48ac77a30 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
-.TH LIBPNGPF 3 "July 5, 2015"
+.TH LIBPNGPF 3 "July 9, 2015"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.6.18beta10
+libpng \- Portable Network Graphics (PNG) Reference Library 1.6.18rc01
(private functions)
.SH SYNOPSIS
\fB#include \fI"pngpriv.h"
diff --git a/png.5 b/png.5
index 73ab9ffe4..645030a0f 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "July 5, 2015"
+.TH PNG 5 "July 9, 2015"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/png.c b/png.c
index 627879e41..1155b1994 100644
--- a/png.c
+++ b/png.c
@@ -14,7 +14,7 @@
#include "pngpriv.h"
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_6_18beta10 Your_png_h_is_not_version_1_6_18beta10;
+typedef png_libpng_version_1_6_18rc01 Your_png_h_is_not_version_1_6_18rc01;
/* Tells libpng that we have already handled the first "num_bytes" bytes
* of the PNG file signature. If the PNG data is embedded into another
@@ -766,13 +766,13 @@ png_get_copyright(png_const_structrp png_ptr)
#else
# ifdef __STDC__
return PNG_STRING_NEWLINE \
- "libpng version 1.6.18beta10 - July 5, 2015" PNG_STRING_NEWLINE \
+ "libpng version 1.6.18rc01 - July 9, 2015" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2015 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE;
# else
- return "libpng version 1.6.18beta10 - July 5, 2015\
+ return "libpng version 1.6.18rc01 - July 9, 2015\
Copyright (c) 1998-2015 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index 16ad47621..57752dbe3 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.6.18beta10, (PENDING RELEASE)
+ * libpng version 1.6.18rc01, (PENDING RELEASE)
*
* Copyright (c) 1998-2015 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngtest.c b/pngtest.c
index ba8fcd9b9..85cabedcd 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -2028,4 +2028,4 @@ main(void)
#endif
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_6_18beta10 Your_png_h_is_not_version_1_6_18beta10;
+typedef png_libpng_version_1_6_18rc01 Your_png_h_is_not_version_1_6_18rc01;
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index 18de3acc9..8ac6d5c14 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.6.18beta10 - July 5, 2015
+libpng version 1.6.18rc01 - July 9, 2015
Copyright (c) 1998-2010 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 3481c8c1a..85c9c3f79 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source
*
- * libpng version 1.6.18beta10 - July 5, 2015
+ * libpng version 1.6.18rc01 - July 9, 2015
*
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
*
diff --git a/scripts/README.txt b/scripts/README.txt
index f41cd9300..a129f1da4 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,9 +1,9 @@
-Makefiles for libpng version 1.6.18beta10 - July 5, 2015
+Makefiles for libpng version 1.6.18rc01 - July 9, 2015
pnglibconf.h.prebuilt => Stores configuration settings
makefile.linux => Linux/ELF makefile
- (gcc, creates libpng16.so.16.1.6.18beta10)
+ (gcc, creates libpng16.so.16.1.6.18rc01)
makefile.gcc => Generic makefile (gcc, creates static libpng.a)
makefile.knr => Archaic UNIX Makefile that converts files with
ansi2knr (Requires ansi2knr.c from
@@ -33,12 +33,12 @@ pnglibconf.h.prebuilt => Stores configuration settings
makefile.os2 => OS/2 Makefile (gcc and emx, requires libpng.def)
makefile.sco => For SCO OSr5 ELF and Unixware 7 with Native cc
makefile.sggcc => Silicon Graphics (gcc,
- creates libpng16.so.16.1.6.18beta10)
+ creates libpng16.so.16.1.6.18rc01)
makefile.sgi => Silicon Graphics IRIX makefile (cc, creates static lib)
makefile.solaris => Solaris 2.X makefile (gcc,
- creates libpng16.so.16.1.6.18beta10)
+ creates libpng16.so.16.1.6.18rc01)
makefile.so9 => Solaris 9 makefile (gcc,
- creates libpng16.so.16.1.6.18beta10)
+ creates libpng16.so.16.1.6.18rc01)
makefile.std => Generic UNIX makefile (cc, creates static libpng.a)
makefile.sunos => Sun makefile
makefile.32sunu => Sun Ultra 32-bit makefile
diff --git a/scripts/def.c b/scripts/def.c
index 1cae8ce75..468f4aaa5 100644
--- a/scripts/def.c
+++ b/scripts/def.c
@@ -21,7 +21,7 @@ PNG_DFN "OS2 DESCRIPTION "PNG image compression library""
PNG_DFN "OS2 CODE PRELOAD MOVEABLE DISCARDABLE"
PNG_DFN ""
PNG_DFN "EXPORTS"
-PNG_DFN ";Version 1.6.18beta10"
+PNG_DFN ";Version 1.6.18rc01"
#define PNG_EXPORTA(ordinal, type, name, args, attributes)\
PNG_DFN "@" SYMBOL_PREFIX "@@" name "@"
diff --git a/scripts/libpng-config-head.in b/scripts/libpng-config-head.in
index 8f54932e3..fbcfe2b7a 100644
--- a/scripts/libpng-config-head.in
+++ b/scripts/libpng-config-head.in
@@ -11,7 +11,7 @@
# Modeled after libxml-config.
-version=1.6.18beta10
+version=1.6.18rc01
prefix=""
libdir=""
libs=""
diff --git a/scripts/libpng.pc.in b/scripts/libpng.pc.in
index 14d9ce3f1..fb22c1dbc 100644
--- a/scripts/libpng.pc.in
+++ b/scripts/libpng.pc.in
@@ -5,6 +5,6 @@ includedir=@includedir@/libpng16
Name: libpng
Description: Loads and saves PNG files
-Version: 1.6.18beta10
+Version: 1.6.18rc01
Libs: -L${libdir} -lpng16
Cflags: -I${includedir}
diff --git a/scripts/makefile.ne12bsd b/scripts/makefile.ne12bsd
index 405d63cb9..2dd540c1a 100644
--- a/scripts/makefile.ne12bsd
+++ b/scripts/makefile.ne12bsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include/libpng16
LIB= png16
SHLIB_MAJOR= 0
-SHLIB_MINOR= 1.6.18beta10
+SHLIB_MINOR= 1.6.18rc01
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.netbsd b/scripts/makefile.netbsd
index f2e9e7834..5f6a79189 100644
--- a/scripts/makefile.netbsd
+++ b/scripts/makefile.netbsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include
LIB= png
SHLIB_MAJOR= 16
-SHLIB_MINOR= 1.6.18beta10
+SHLIB_MINOR= 1.6.18rc01
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.openbsd b/scripts/makefile.openbsd
index 5c7a5ef7b..64aed914b 100644
--- a/scripts/makefile.openbsd
+++ b/scripts/makefile.openbsd
@@ -11,7 +11,7 @@ LIBDIR= ${PREFIX}/lib
MANDIR= ${PREFIX}/man/cat
SHLIB_MAJOR= 16
-SHLIB_MINOR= 1.6.18beta10
+SHLIB_MINOR= 1.6.18rc01
LIB= png
SRCS= png.c pngerror.c pngget.c pngmem.c pngpread.c \
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index 634c99341..e8cea9f9e 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -1,8 +1,8 @@
-/* libpng 1.6.18beta10 STANDARD API DEFINITION */
+/* libpng 1.6.18rc01 STANDARD API DEFINITION */
/* pnglibconf.h - library build configuration */
-/* Libpng version 1.6.18beta10 - July 5, 2015 */
+/* Libpng version 1.6.18rc01 - July 9, 2015 */
/* Copyright (c) 1998-2014 Glenn Randers-Pehrson */
diff --git a/scripts/symbols.def b/scripts/symbols.def
index 5744a94b7..b7daff027 100644
--- a/scripts/symbols.def
+++ b/scripts/symbols.def
@@ -1,4 +1,4 @@
-;Version 1.6.18beta10
+;Version 1.6.18rc01
;--------------------------------------------------------------
; LIBPNG symbol list as a Win32 DEF file
; Contains all the symbols that can be exported from libpng
diff --git a/png.h b/png.h
index 62c0cc8fd..bc28740ec 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.6.18beta10, July 9, 2015
*
* Copyright (c) 1998-2015 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -12,7 +12,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.6.18beta10, July 9, 2015: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -216,7 +216,8 @@
* 1.6.17beta01-06 16 10617 16.so.16.17[.0]
* 1.6.17rc01-06 16 10617 16.so.16.17[.0]
* 1.6.17 16 10617 16.so.16.17[.0]
- * 1.6.18beta01-10 16 10618 16.so.16.18[.0]
+ * 1.6.18beta01-09 16 10618 16.so.16.18[.0]
+ * 1.6.18rc01 16 10618 16.so.16.18[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -248,7 +249,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.0.7, July 1, 2000, through 1.6.18beta10, July 9, 2015, are
* Copyright (c) 2000-2002, 2004, 2006-2015 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.0.6
* with the following individuals added to the list of Contributing Authors:
@@ -363,7 +364,7 @@
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.6.18beta10 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -425,9 +426,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.6.18beta10"
+#define PNG_LIBPNG_VER_STRING "1.6.18rc01"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.6.18beta10 - July 9, 2015\n"
+ " libpng version 1.6.18rc01 - July 9, 2015\n"
#define PNG_LIBPNG_VER_SONUM 16
#define PNG_LIBPNG_VER_DLLNUM 16
@@ -441,7 +442,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 10
+#define PNG_LIBPNG_VER_BUILD 01
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -458,7 +459,7 @@
#define PNG_LIBPNG_BUILD_SPECIAL 32 /* Cannot be OR'ed with
PNG_LIBPNG_BUILD_PRIVATE */
-#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_BETA
+#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_RC
/* Careful here. At one time, Guy wanted to use 082, but that would be octal.
* We must not include leading zeros.
@@ -571,7 +572,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_6_18beta10;
+typedef char* png_libpng_version_1_6_18rc01;
/* Basic control structions. Read libpng-manual.txt or libpng.3 for more info.
*
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.6.18beta10, July 9, 2015
+ * libpng version 1.6.18rc01, July 9, 2015
*
* Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -12,7 +12,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.6.18beta10, July 9, 2015: Glenn
+ * libpng versions 0.97, January 1998, through 1.6.18rc01, July 9, 2015: Glenn
* See also "Contributing Authors", below.
*
@@ -248,7 +249,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.0.7, July 1, 2000, through 1.6.18beta10, July 9, 2015, are
+ * libpng versions 1.0.7, July 1, 2000, through 1.6.18rc01, July 9, 2015, are
* Copyright (c) 2000-2002, 2004, 2006-2015 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.0.6
@@ -363,7 +364,7 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.6.18beta10 are Y2K compliant. It is my belief that
+ * upward through 1.6.18rc01 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*